# coding: utf-8

"""
    Cochl.Sense API

    Cochl.Sense API allows to detect what is contained inside sound data. Send audio data over the internet to discover what it contains. 

    The version of the OpenAPI document: v1.7.11
    Contact: support@cochl.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SessionType(str, Enum):
    """
    Whether a session is File Session or Stream Session 
    """

    """
    allowed enum values
    """
    STREAM = 'stream'
    FILE = 'file'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SessionType from a JSON string"""
        return cls(json.loads(json_str))


