# coding: utf-8

"""
    Cochl.Sense API

    Cochl.Sense API allows to detect what is contained inside sound data. Send audio data over the internet to discover what it contains. 

    The version of the OpenAPI document: v1.7.11
    Contact: support@cochl.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from cochl_sense_api.models.sense import Sense
from cochl_sense_api.models.session_refs import SessionRefs
from typing import Optional, Set
from typing_extensions import Self

class SessionStatus(BaseModel):
    """
    Contains all the data for the product Cochl.Sense 
    """ # noqa: E501
    state: StrictStr = Field(description="State in which the session is ")
    error: Optional[StrictStr] = Field(default=None, description="An error occurred during the session ")
    refs: SessionRefs
    inference: Sense
    __properties: ClassVar[List[str]] = ["state", "error", "refs", "inference"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['writable', 'readonly']):
            raise ValueError("must be one of enum values ('writable', 'readonly')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SessionStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of refs
        if self.refs:
            _dict['refs'] = self.refs.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inference
        if self.inference:
            _dict['inference'] = self.inference.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SessionStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "state": obj.get("state"),
            "error": obj.get("error"),
            "refs": SessionRefs.from_dict(obj["refs"]) if obj.get("refs") is not None else None,
            "inference": Sense.from_dict(obj["inference"]) if obj.get("inference") is not None else None
        })
        return _obj


