# coding: utf-8

# flake8: noqa

"""
    Cochl.Sense API

    Cochl.Sense API allows to detect what is contained inside sound data. Send audio data over the internet to discover what it contains. 

    The version of the OpenAPI document: v1.7.11
    Contact: support@cochl.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.7.11"

# import apis into sdk package
from cochl_sense_api.api.audio_session_api import AudioSessionApi

# import ApiClient
from cochl_sense_api.api_response import ApiResponse
from cochl_sense_api.api_client import ApiClient
from cochl_sense_api.configuration import Configuration
from cochl_sense_api.exceptions import OpenApiException
from cochl_sense_api.exceptions import ApiTypeError
from cochl_sense_api.exceptions import ApiValueError
from cochl_sense_api.exceptions import ApiKeyError
from cochl_sense_api.exceptions import ApiAttributeError
from cochl_sense_api.exceptions import ApiException

# import models into sdk package
from cochl_sense_api.models.audio_chunk import AudioChunk
from cochl_sense_api.models.create_session import CreateSession
from cochl_sense_api.models.created_session import CreatedSession
from cochl_sense_api.models.generic_error import GenericError
from cochl_sense_api.models.page import Page
from cochl_sense_api.models.predict_request import PredictRequest
from cochl_sense_api.models.predict_response import PredictResponse
from cochl_sense_api.models.sense import Sense
from cochl_sense_api.models.sense_event import SenseEvent
from cochl_sense_api.models.sense_event_tag import SenseEventTag
from cochl_sense_api.models.session_refs import SessionRefs
from cochl_sense_api.models.session_result import SessionResult
from cochl_sense_api.models.session_status import SessionStatus
from cochl_sense_api.models.session_type import SessionType
from cochl_sense_api.models.update_session import UpdateSession
